@@ -53,7 +53,7 @@ def getDistinctWordsTimestampScript(script, matchingDistinct):
     for matchingDistinctWord in matchingDistinct:
         for content in matchingDistinctWord["content"]:
             script[content["index"]]["timestamp"] = content["timestamp"]
-            script[content["index"]]["distinct"] = matchingDistinctWord
+            script[content["index"]]["distinct"] = content
     return script
 
 
@@ -96,7 +96,7 @@ def markScriptWithRareWordsTimestamp(nlp, script, subs):
     # json.dump(scriptDistinct, file0, indent=4)
     # file0 = open("matchingHelp.json", "w+")
     # json.dump(matchingDistinct, file0, indent=4)
-    # file0 = open("kingkong.json", "w+")
-    # json.dump(scriptDistinctTimestamp, file0, indent=4)
+    file0 = open("test.json", "w+")
+    json.dump(scriptDistinctTimestamp, file0, indent=4)
 
     return (script, scriptDistinctTimestamp, subsDistinctTimestamp)
