@@ -19,40 +19,46 @@ from subtitle_sync.utils.fillTimetamps import fillTimestamps
 
 
 def sync(moviePath, subsPath):
-    subtitle = open(subsPath, "r")
-    subtitle = list(srt.parse(subtitle.read()))
+    # subtitle = open(subsPath, "r")
+    # subtitle = list(srt.parse(subtitle.read()))
 
-    script = open(moviePath, "rb")
-    script = json.load(script)
-    pureScript = copy.copy(script)
+    # script = open(moviePath, "rb")
+    # script = json.load(script)
+    # pureScript = copy.copy(script)
 
-    nlp = spacy.load("en_core_web_lg")
+    # nlp = spacy.load("en_core_web_lg")
 
-    # explicitly adding component to pipeline
-    # (recommended - makes it more readable to tell what's going on)
-    nlpSentece = spacy.blank("en")
-    nlpSentece.add_pipe(PySBDFactory(nlpSentece))
+    # # explicitly adding component to pipeline
+    # # (recommended - makes it more readable to tell what's going on)
+    # nlpSentece = spacy.blank("en")
+    # nlpSentece.add_pipe(PySBDFactory(nlpSentece))
 
-    custom_lookup = {
-        "til": "until",
-    }
+    # custom_lookup = {
+    #     "til": "until",
+    # }
 
-    def change_lemma_property(doc):
-        for token in doc:
-            if token.text in custom_lookup:
-                token.lemma_ = custom_lookup[token.text]
-        return doc
+    # def change_lemma_property(doc):
+    #     for token in doc:
+    #         if token.text in custom_lookup:
+    #             token.lemma_ = custom_lookup[token.text]
+    #     return doc
 
-    nlp.add_pipe(change_lemma_property, first=True)
+    # nlp.add_pipe(change_lemma_property, first=True)
 
-    subtitle = formatSubs(nlpSentece, subtitle)
-    script = formatScript(nlpSentece, script)
+    # subtitle = formatSubs(nlpSentece, subtitle)
+    # script = formatScript(nlpSentece, script)
 
-    (
-        script,
-        scriptWithTimestamp,
-        subsWithTimestamp,
-    ) = markScriptWithRareWordsTimestamp(nlp, script, subtitle)
+    # (
+    #     script,
+    #     scriptWithTimestamp,
+    #     subsWithTimestamp,
+    # ) = markScriptWithRareWordsTimestamp(nlp, script, subtitle)
+
+    pureScript = open(moviePath, "rb")
+    pureScript = json.load(pureScript)
+
+    scriptWithTimestamp = open("./test.json", "rb")
+    scriptWithTimestamp = json.load(scriptWithTimestamp)
 
     pureScript = tagTimestampToScript(pureScript, scriptWithTimestamp)
 
